Leaf = {}
function Leaf:new(object, x, y)
	object = object or {}
	setmetatable(object, self)
	self.__index = self
	self.x = x
	self.y = y
	self.image = love.graphics.newImage('gfx/leaf3.png')
	self.angle = 0
	self.cx = 0
	self.cy = 0
	self.cradius = 16
	
	self.anchor = love.physics.newBody(World, self.x, self.y, 'static')
	self.anchor_shape = love.physics.newCircleShape(3)
	self.fix = love.physics.newFixture(self.anchor, self.anchor_shape)
	self.body = love.physics.newBody(World, self.x, self.y-130, 'dynamic')
	self.shape = love.physics.newRectangleShape(4, 260)
	self.fixture = love.physics.newFixture(self.body, self.shape)
	self.fixture:setUserData('Leaf')
	
	self.joint = love.physics.newRevoluteJoint(self.anchor, self.body, self.x, self.y, false)
	
	self:calculateControlPoint()
	return object
end

function Leaf:calculateControlPoint()
	self.cx = self.x + 260 * math.sin(self.angle)
	self.cy = self.y - 260 * math.cos(self.angle)
end


function Hypot(a, b)
	return math.sqrt(a * a + b * b)
end

function love.load()
	love.window.setMode(800, 600, {resizable=false})
	love.graphics.setBackgroundColor(0.0, 0.0, 0.0, 1.0)
	World = love.physics.newWorld(0, 100, true)
	local a, b = Leaf:new(nil, 400, 600), Leaf:new(nil, 400, 300)
	LEAFS = {a, b}
	love.window.setTitle ("Hanenbow")
end
    
function love.update(dt)
	World:update(dt)
	mousex, mousey = love.mouse.getPosition()
	-- check if mouse on control point
	for i = 1, #LEAFS do
		if Hypot(mousex - LEAFS[i].cx, mousey - LEAFS[i].cy) <= (LEAFS[i].cradius + 16) then
			if love.mouse.isDown(1) then
				-- left mouse button is pressed ?
				angle = math.rad(180) - math.atan2(mousex - LEAFS[i].x, mousey - LEAFS[i].y)
				LEAFS[i].angle = angle
				LEAFS[i].body:setAngle(angle)
				LEAFS[i]:calculateControlPoint()
			end
		end
	end
end
    
    
function love.draw()
	
	for i = 1, #LEAFS do
		-- draw image
		love.graphics.draw(LEAFS[i].image, LEAFS[i].x, LEAFS[i].y, angle, 1, 1, LEAFS[i].image:getWidth()/2, LEAFS[i].image:getHeight())
		-- draw circle at the end of leaf
		love.graphics.circle('line', LEAFS[i].cx, LEAFS[i].cy, LEAFS[i].cradius)
		-- draw radius around mouse
		love.graphics.circle('line', mousex, mousey, 16)
		-- draw anchor centers
		local x, y, z, h = LEAFS[i].joint:getAnchors()
		love.graphics.circle('fill', x, y, 6)
		love.graphics.circle('line', z, h, 6)
		-- draw main body
		love.graphics.polygon('line', LEAFS[i].body:getWorldPoints(LEAFS[i].shape:getPoints()))
	end
end